@@ -22,6 +22,7 @@ from masakari.policies import hosts
 from masakari.policies import notifications
 from masakari.policies import segments
 from masakari.policies import versions
+from masakari.policies import vmoves
 
 
 def list_rules():
@@ -31,5 +32,6 @@ def list_rules():
         hosts.list_rules(),
         notifications.list_rules(),
         segments.list_rules(),
-        versions.list_rules()
+        versions.list_rules(),
+        vmoves.list_rules()
     )
