@@ -336,8 +336,12 @@ class StringLengthTestCase(APIValidationTestCase):
                          'Validation succeeded.')
 
     def test_validate_string_length_fails(self):
-        detail = ("Invalid input for field/attribute foo. Value: ."
-                  " '' is too short")
+        detail = [
+            "Invalid input for field/attribute foo. Value: . '' "
+            "is too short",  # jsonschema < 4.23.0
+            "Invalid input for field/attribute foo. Value: . '' "
+            "should be non-empty",  # jsonschema >= 4.23.0
+        ]
         self.check_validation_error(self.post, body={'foo': ''},
                                     expected_detail=detail)
 
